@@ -63,10 +63,11 @@ and set up the location to the native optimizer in ~/.emscripten
 temp_files = shared.configuration.get_temp_files()
 
 def build(src, result_libs, args=[]):
-  temp = temp_files.get('.cpp').name
-  open(temp, 'w').write(src)
-  temp_js = temp_files.get('.js').name
-  shared.Building.emcc(temp, args, output_filename=temp_js)
+  with temp_files.get_file('.cpp') as temp:
+    open(temp, 'w').write(src)
+    temp_js = temp_files.get('.js').name
+    shared.Building.emcc(temp, args, output_filename=temp_js)
+
   assert os.path.exists(temp_js), 'failed to build file'
   if result_libs:
     for lib in result_libs:
@@ -144,6 +145,13 @@ if operation == 'build':
       build('''
         int main() {}
       ''', ['optimizer.2.exe'], ['-O2'])
+    elif what == 'wasm_compiler_rt':
+      if shared.get_llvm_target() == shared.WASM_TARGET:
+        build('''
+          int main() {}
+        ''', ['wasm_compiler_rt.a'], ['-s', 'BINARYEN=1'])
+      else:
+        shared.logging.warning('wasm_compiler_rt not built when using JSBackend')
     elif what == 'zlib':
       build_port('zlib', 'libz.a', ['-s', 'USE_ZLIB=1'])
     elif what == 'bullet':
@@ -175,4 +183,3 @@ if operation == 'build':
 else:
   shared.logging.error('unfamiliar operation: ' + operation)
   sys.exit(1)
-
