@@ -308,7 +308,7 @@ var LibraryPThread = {
         };
 
         worker.onerror = function(e) {
-          Module['printErr']('pthread sent an error! ' + e.message);
+          Module['printErr']('pthread sent an error! ' + e.filename + ':' + e.lineno + ': ' + e.message);
         };
 
         // Allocate tempDoublePtr for the worker. This is done here on the worker's behalf, since we may need to do this statically
@@ -321,8 +321,12 @@ var LibraryPThread = {
             url: currentScriptUrl,
             buffer: HEAPU8.buffer,
             tempDoublePtr: tempDoublePtr,
+            TOTAL_MEMORY: TOTAL_MEMORY,
+            STATICTOP: STATICTOP,
+            DYNAMIC_BASE: DYNAMIC_BASE,
+            DYNAMICTOP_PTR: DYNAMICTOP_PTR,
             PthreadWorkerInit: PthreadWorkerInit
-          }, [HEAPU8.buffer]);
+          });
         PThread.unusedWorkerPool.push(worker);
       }
     },
